available_subjects: Available Subjects

View source: R/available_subjects.R

available_subjectsR Documentation

Available Subjects

Description

Returns a list of available subjects from the Ipeadata API.

Usage

available_subjects(language = c("en", "br"), label = TRUE)

Arguments

language

A character string specifying the language. Available options are English ("en", default) and Brazilian Portuguese ("br").

label

Logical. If TRUE (default), variable labels are added to the output data frame using sjlabelled::set_label().

Value

A data frame containing the subject code and subject name.


ipeadatar documentation built on May 28, 2026, 5:08 p.m.