available_territories: Available Territorial Divisions

View source: R/available_territories.R

available_territoriesR Documentation

Available Territorial Divisions

Description

Returns a list of available Brazilian territorial divisions from the Ipeadata API.

Usage

available_territories(language = c("en", "br"), label = TRUE)

Arguments

language

A character string specifying the language. Available options are English ("en", default) and Brazilian Portuguese ("br").

label

Logical. If TRUE (default), variable labels are added to the output data frame using sjlabelled::set_label().

Value

A data frame containing the unit type, code, name, and area (in km²) of Brazilian territorial divisions.


ipeadatar documentation built on May 28, 2026, 5:08 p.m.