| ipeadata | R Documentation |
Returns the data associated with requested Ipeadata series.
ipeadata(code, language = c("en", "br"), label = TRUE, quiet = FALSE)
code |
A character vector of Ipeadata series codes. |
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
quiet |
Logical. If |
A data frame containing the Ipeadata code, date, value, territorial unit name, and territorial code of the requested series.
Ipeadata codes may be obtained using available_series().
This package uses the Ipeadata API: https://www.ipeadata.gov.br/
available_series(), available_territories()
data <- ipeadata(
code = "PRECOS12_IPCA12",
language = "en"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.