ipeadatar-package: ipeadatar: API Wrapper for Ipeadata

ipeadatar-packageR Documentation

ipeadatar: API Wrapper for Ipeadata

Description

Provides direct access to the macroeconomic, financial, and regional database maintained by the Institute for Applied Economic Research (Ipea) via the Ipeadata API.

Author(s)

Maintainer: Luiz Eduardo Gomes luiz.gomes@ipea.gov.br (ORCID)

Authors:

Other contributors:

See Also

Useful links:


ipeadatar documentation built on May 28, 2026, 5:08 p.m.