| metadata | R Documentation |
Returns metadata information for requested Ipeadata series.
metadata(code, language = c("en", "br"), label = TRUE, quiet = FALSE)
code |
A character vector of Ipeadata series codes. |
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
quiet |
Logical. If |
A data frame containing metadata for the requested Ipeadata series, including code, name, comments, last update, theme, source, frequency, unit, multiplier, status, subject code, and country code.
The original language of series names and comments is preserved.
Ipeadata codes may be obtained using available_series().
This package uses the Ipeadata API: https://www.ipeadata.gov.br/
available_series(), available_subjects(),
available_territories()
meta <- metadata(code = "PRECOS12_IPCA12")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.