View source: R/available_subjects.R
| available_subjects | R Documentation |
Returns a list of available subjects from the Ipeadata API.
available_subjects(language = c("en", "br"), label = TRUE)
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
A data frame containing the subject code and subject name.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.