View source: R/available_territories.R
| available_territories | R Documentation |
Returns a list of available Brazilian territorial divisions from the Ipeadata API.
available_territories(language = c("en", "br"), label = TRUE)
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
A data frame containing the unit type, code, name, and area (in km²) of Brazilian territorial divisions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.