| ipeadatar-package | R Documentation |
Provides direct access to the macroeconomic, financial, and regional database maintained by the Institute for Applied Economic Research (Ipea) via the Ipeadata API.
Maintainer: Luiz Eduardo Gomes luiz.gomes@ipea.gov.br (ORCID)
Authors:
Luiz Eduardo Gomes luiz.gomes@ipea.gov.br (ORCID)
Other contributors:
Daniel Herszenhut daniel.santos@ipea.gov.br (ORCID) [contributor]
Instituto de Pesquisa Econômica Aplicada (Ipea) [copyright holder, funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.