View source: R/search_series.R
| search_series | R Documentation |
Searches for Ipeadata series matching the provided terms.
search_series(terms = NULL, language = c("en", "br"), label = TRUE)
terms |
A character vector of search terms. |
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
A data frame containing the Ipeadata code, name, theme, source, frequency, last update, and activity status of the matched series.
The original language of the series names is preserved.
search_series(terms = "rural")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.